pub struct StdLib { /* private fields */ }Expand description
Standard library module for Cobble Provides runtime support for event handling and built-in functions
Implementations
Sourceimpl StdLib
impl StdLib
pub fn new() -> Self
Sourcepub fn add_event_listener(
&mut self,
event_type: EventType,
function_name: String,
)
pub fn add_event_listener( &mut self, event_type: EventType, function_name: String, )
Register an event handler function
Sourcepub fn get_event_handlers(&self, event_type: &EventType) -> Vec<String>
pub fn get_event_handlers(&self, event_type: &EventType) -> Vec<String>
Get all handlers for a specific event
Generate the minecraft function tags for load and tick events