pub struct CommandValidator { /* private fields */ }Implementations
Sourceimpl CommandValidator
impl CommandValidator
pub fn from_file(path: &Path) -> Result<Self, String>
pub fn from_json_str(content: &str) -> Result<Self, String>
Sourcepub fn validate_command(&self, command: &str) -> Result<(), String>
pub fn validate_command(&self, command: &str) -> Result<(), String>
Validate a single command string. Returns Ok(()) if the command is valid, Err with a message otherwise.
Sourcepub fn validate_command_detailed(
&self,
command: &str,
) -> Result<(), CommandValidationError>
pub fn validate_command_detailed( &self, command: &str, ) -> Result<(), CommandValidationError>
Validate a single command string and retain the best-known error cursor.
Sourcepub fn validate_mcfunction(&self, content: &str) -> Vec<ValidationError>
pub fn validate_mcfunction(&self, content: &str) -> Vec<ValidationError>
Validate an entire .mcfunction file. Returns a list of errors found.
Sourcepub fn validate_datapack(&self, dir: &Path) -> ValidationReport
pub fn validate_datapack(&self, dir: &Path) -> ValidationReport
Validate all .mcfunction files in a datapack directory.